function [ LWD, Probe_1, ip1 ] = DecayWood( LWD, year, Data, K_decay, K_break, Probe_1, ip1)
%DecayWood.m is a function that calculates the annual decay of the wood
%pieces stored in data matrix LWD, and then determines whether or not they
%are likely to break as a result of weathering etc. during a given year
%   Detailed explanation goes here

%modify the piece diameter
    LWD(Data,2) = LWD(Data,2) - LWD(Data,2) * K_decay; 

%determine which peices break based on shape factor H/D
    ShpFac = LWD(Data,1)./LWD(Data,2);      %calculate the shape factor for each peice
    P_break = K_break .* ShpFac./100;       %assume that the P increases with ShpFac linearly, and spec. K_break for shape factor of 100
    T_break = rand(numel(P_break),1);
    Break_Ind = find(T_break < P_break);

    %only run this part if there are pieces that need breaking
    if isempty(Break_Ind) == 0
        %loop through all pieces that break
        for j = 1:numel(Break_Ind)
            H_target = LWD(Break_Ind(j),1);     %retrieve the length from LWD
            Diam_target = LWD(Break_Ind(j),2);  %retrieve the diameter from LWD
            Vol_target = LWD(Break_Ind(j),5);   %retrieve the volume of stored sediment

            KeyPiece = LWD(Break_Ind(j),7) > 0; %check the jam age to see if this is a key piece for a jam
            InJam = LWD(Break_Ind(j),6) > 0;    %check if the piece is already in a jam

            H1 = H_target/4 + H_target/2 * rand(1);  %breakage occurs randomly between 25% and 75% of the length
            H2 = H_target - H1;
            
            %this is the procedure for non key pieces, and pieces
            %not in a jam
            if KeyPiece == 0 && InJam == 0
                %keep part of the wood in the original row of LWD and assume it
                %does not move or change orientation
                LWD(Break_Ind(j),1) = H1;
                LWD(Break_Ind(j),5) = (H1 ./ H_target) .* Vol_target;   %retain only a linear proportion of stored volume
                LWD(Break_Ind(j),8) = 0.95;  %assume the bank peice falls in
                
                %put the other part in the next available row of LWD, assuming
                %it moves and ends up more or less parallel to the flow with
                %normal variations about 180 mean, 12 std dev, and assume
                %that the piece releases all stored sediment
                A_Row = find(LWD(:,1) == 0,1, 'first');   %find the next available row to store data

                %re-orient the piece
                if rand(1) < (1/3)
                    %one third of the time, allocate new orientation skewed
                    %to flow
                    NewOr = 120 + 30*rand(1);
                    %'or reset 1/3'
                else
                    %two thirds of the time, allocation orientation
                    %parallel to flow
                    NewOr = 150 + 30*rand(1);
                    %'or reset 2/3'
                end
                LWD(A_Row,1:5) = [H2 Diam_target 0 NewOr 0];
                LWD(A_Row,8) = 0.95;
                LWD(A_Row,6) = 0;
                LWD(A_Row,7) = 0;
            end

            if KeyPiece == 1 && LWD(Break_Ind(j),8) == 0.05
                
                %for fully suspended key peices, the first break changes LW
                %function class but not the length
                LWD(Break_Ind(j),8) = 0.5;
                LWD(Break_Ind(j),3) = 0;    %and reset the age to 0 to begin trapping sediment
                
            elseif KeyPiece == 1 && LWD(Break_Ind(j),8) > 0.05
                %'break jam' once the second break occurs
                LWD(Break_Ind(j),1) = H1;
                LWD(Break_Ind(j),8) = 0.95; %assume the peice enters the channel
                %LWD(Break_Ind(j),5) = 0;    %remove all of the stored sediment associated with the key piece

                %put the other part in the next available row of LWD, assuming
                %it moves and ends up more or less parallel to the flow with
                %normal variations about 180 mean, 12 std dev, and assume
                %that the piece releases all stored sediment
                A_Row = find(LWD(:,1) == 0,1, 'first');   %find the next available row to store data

                %re-orient the piece
                if rand(1) < (1/3)
                    %one third of the time, allocate new orientation skewed
                    %to flow
                    NewOr = 120 + 30*rand(1);
                    %'or reset 1/3'
                else
                    %two thirds of the time, allocation orientation
                    %parallel to flow
                    NewOr = 150 + 30*rand(1);
                    %'or reset 2/3'
                end

                LWD(A_Row,1:5) = [H2 Diam_target 0 NewOr 0];
                LWD(A_Row,6) = 0;
                LWD(A_Row,7) = 0;
                LWD(A_Row,8) = 0.95;

                %retrieve the jam id number, and identify LW in the jam
                ID_n = LWD(Break_Ind(j),6);
                InJam = find(LWD(:,6)==ID_n);
                
                %use Probe_1 to record the age of jam breakage, year of
                %breakage, number of LW pieces, and volume of sediment
                %stored
                Probe_1(ip1,1:4) = [LWD(Break_Ind(j),3) year numel(InJam) sum(LWD(InJam,5))];
                ip1 = ip1 + 1;

                
                %LWD(InJam,:)
                LWD(InJam,3) = 0;   %reset age
                LWD(InJam,5) = 0;   %reset storage volume
                LWD(InJam,6) = 0;   %remove the jam ID and jam age class for all pieces
                LWD(InJam,7) = 0;
                %LWD(InJam,:)
                
                %reorient the pieces
                for i = 1:numel(InJam)
                    if rand(1) < (1/3)
                        %one third of the time, allocate new orientation skewed
                        %to flow
                        NewOr(i) = 120 + 30*rand(1);
                        %'or reset 1/3'
                    else
                        %two thirds of the time, allocation orientation
                        %parallel to flow
                        NewOr(i) = 150 + 30*rand(1);
                        %'or reset 2/3'
                    end
                end
                LWD(InJam, 4) = NewOr;

            end


        end

    end
    
    %remove the jam labesl and stored sediment for all failed jams
    AllJams = unique(LWD(:,6));
    AllJams(AllJams ==0) = [];
    RemJams = unique(LWD(LWD(:,7)>0,6));
    
    for R = 1 : numel(AllJams);
        
        %find all LW supposedly in a jam w/o a key piece    
        if sum(AllJams(R)==RemJams) < 1;
            InJam = find(LWD(:,6)==AllJams(R));
            LWD(InJam,3) = 0;   %reset age
            LWD(InJam,5) = 0;   %reset storage volume
            LWD(InJam,6) = 0;   %remove the jam ID and jam age class for all pieces
        end
            
    end
    
    %increase age by 1 for all pieces
    LWD(Data,3) = LWD(Data,3) + 1;  

    
end

