function [LWD] = MoveWood(LWD, Data, W_ch, L_ch, d_reg, Nkey)
%MoveWood.m is a function that moves mobile pieces of wood and stores the
%results in the data matrix LWD
%   Detailed explanation goes here

    %specify a filter to get the real data
    %Data = find(LWD(:,1) > 0);
                
    for Mi = 1 : numel(Data)
        %%%%first calculate P of movement based on length
        P_hw = erfc(3 .* (LWD(Data(Mi),1)./W_ch - 0.5))/2;     

        %%%second calculate P of movement based on orientation
        P_o = erfc(2 .* (abs(LWD(Data(Mi),4) - 90) ./ 90 - 0.9))/2;

        %do the following if the piece in question is not
        %associated with a jam. pieces associated with a jam
        %will only move once the key piece breaks. Also, require the LW
        %peice to be fully functioning before it can move
        
        
        %%%third, determine if the diameter of the LW PIECE is a limitting
        %%%factor, assuming pieces will move once Diam < 2*local depth
        
        LocalDepth = d_reg + (1/3)*d_reg*randn(1);  %assume that depths are normally distributed with a standard deviation 1/3 of the mean
        RelDepth = LocalDepth / LWD(Data(Mi),2);    %determine the relative depth (LocalDepth/LW diameter), which must be > 0.5 for entrainment to occur
        
        %apply movement probabilities to all pieces where RelDepth > 0.5
        %that are not in a jam, and that are not suspended on the channel
        %banks
        if rand(1) < P_hw * P_o && RelDepth > 0.5 && LWD(Data(Mi),6) == 0 && LWD(Data(Mi),8) == 0.95
            %reset time
            LWD(Data(Mi),3) = 0;
            %'time reset'
            %remove stored sediment
            LWD(Data(Mi),5) = 0;
            %'vol reset'

            H_W = LWD(Data(Mi),1) ./ W_ch;

            %use the exponential fit to Mack Creek, adjusting
            %for 10-year observation period, scaled by the relative depth
            %(for Mack Creek, the relative depth was about 1, but where it
            %is greater, movement distances will be greater, where it is
            %smaller, movement distances will be smaller)
            
            L_travel = RelDepth .* W_ch .* (103.3 / 10)*exp(-3.824*H_W);
            %catch any pieces that move distances greater than the reach
            %length...they will interact with a jam 
            if L_travel > L_ch
                L_travel = L_ch;
            end


            %generate a list of all potential jams
            JamList = unique(LWD(:,6));
            JamList(JamList == 0) = []; %remove the 0 from the list
            NJams = numel(JamList);     %calculate the number of jams from the unique jam labels

            %determine the probability of interacting with a
            %jam based on the number of jams and the length of
            %the reach (P = 1 - P(no interaction)^No. Jams)
            Pjam  = 1 - (1 - L_travel ./ L_ch)^Nkey;


            %determine if this particular piece joins a jam
            if rand(1) < Pjam && isempty(JamList) == 0
                %'joins jam';
                JamSwitch = 1;
                LWD(Data(Mi),6) = JamList(ceil(NJams * rand(1)));
                %assign the piece to one of the existing jams
            else
                JamSwitch = 0;
                LWD(Data(Mi),6) = 0;
            end

            %re-orient the piece, using one rule for pieces in
            %a jam and another for free pieces
            if JamSwitch == 1
                LWD(Data(Mi),4) = 75 + 30*rand(1);  %set the piece to nearly perpendicular if it is in a jam
            elseif JamSwitch == 0
                %set the peice nearly parallel to flow
                if rand(1) < (1/3)
                    %one third of the time, allocate new orientation skewed
                    %to flow
                    LWD(Data(Mi),4) = 120 + 30*rand(1);
                    %'or reset 1/3'
                else
                    %two thirds of the time, allocation orientation
                    %parallel to flow
                    LWD(Data(Mi),4) = 150 + 30*rand(1);
                    %'or reset 2/3'
                end

            end


        end
    end
         

end

