function [ LWD ] = StoreSed( LWD, Data, Q_sed, Dur_flood, L_ch, W_ch, S )
%StoreSed.m is a function that calculates the volume of sediment stored
%each year in association with each LW piece in the data matrix LWD
 
    %calculate the FUNCTIONAL wood load (m3/m2) for the reach (i.e.
    %multiply total wood load by wood function parameter to scale load by
    %estimated piece function)
                LWV = sum(LWD(Data,8).* LWD(Data,1)...  
                .* LWD(Data,2).^2) ./(L_ch.*W_ch);
            
    %calculate the transport efficiency based on wood load,
                %based on Sarah's experiments, the relation is linear...
                TrEf = erf(18 * LWV);
                
    %calculate the total projected area for each piece
                Area_i = (LWD(Data,1) .* LWD(Data,2) .* sind(LWD(Data,4))...
                    + LWD(Data,2).^2 .* abs(cosd(LWD(Data,4))));
                
    %calculate the total potential sediment storage volume for each piece
                LWD(Data,9) = Area_i .* (LWD(Data,2) ./ S) .* LWD(Data,8);
                
    %now calculate the actual trapping rate based on TrEf and residence
    %time for the LW piece            

                TrEf_i = TrEf... %distribute potential trapping action amongst all LW pieces using blockage ratios
                    .* LWD(Data,8) ...  %use the LW function parameter as a surrogate for relative submergence
                    .*Area_i./ sum(Area_i);

                Rate_Const = -25;                                  %set the rate constant for the exponential drop in trapping rate as a function of the volume of stored sediment
                Eff_i = TrEf_i .* exp(Rate_Const .* LWD(Data,5)./LWD(Data,9));   %use an exponential decay model to estimate the trapping rate for each piece
                Vol_i = Eff_i .* Q_sed .* Dur_flood;                %determine the volume of sediment trapped by each piece
                LWD(Data,5) = LWD(Data,5) + Vol_i;                  %add the annual increment of storage to the total stored volume
end

