function [LWD] = Wood_In( H_tr, D_tr, W_ch, L_ch, Dens_tr, LWD )
%Wood_In.m is a function that computes the anuual input of wood to a reach
%as part of the Reach Scale Channel Simulator, determines whether it breaks
%during input, and stores the result in the data matrix
%   Detailed explanation goes here


        N_stems = round(2 .* H_tr .* L_ch .* Dens_tr); %the number of stems is equal to two banks times average tree height * length of the reach * density of trees
        Mort_Rate = 0.002 + 0.001 .* rand(1);   %set the tree fall rate using a specified mean and std. dev. for a normally distributed variable
        N_mort = sum(rand(N_stems,1) <= Mort_Rate);      %calculate the number of tree mortalities for the year using a uniform random variable

        %there will be N_mort trees that fall into the stream every year
        Ang_Mort = 360 .* rand(N_mort,1);       %fall angle for each mortality (angles 0 - 180 fall towards channel, 180 - 360 fall away)
        H_Mort = (H_tr .* (sind(Ang_Mort) - rand(N_mort,1)));% ./ sind(Ang_Mort);   %determine how much of each mortality falls in the channel, assuming a uniform random distance from the bank
        
        %if the top of the tree falls on the other side of the
        %channel, break it there too
        TooLong = find(H_Mort > W_ch);
        
        if isempty(TooLong) == 0
            H_Mort(TooLong) = W_ch;             %using the projected length perpendicular to the channel, cut off the top
            %'shortened'
        end
                
        LWD_in = find(H_Mort > 0);
        
        %determine if there is any LWD to input, then add data if need be
        if isempty(LWD_in) == 0

            N_in = numel(LWD_in);               %determine how many pieces to add

            for i = 1:N_in                      %add data to the matrix LWD

                %ADD the fallen trees to the channel
                A_Row = find(LWD(:,1) == 0,1, 'first');   %find the next available row to store data
                
                LWD(A_Row,1:4) = [H_Mort(LWD_in(i))./sind(Ang_Mort(LWD_in(i)))...   %assign the length of the piece, correcting for fall angle
                                    D_tr...                                         %assign tree diamter
                                    0 ...                                           %set the age of the LWD piece to zero
                                    Ang_Mort(LWD_in(i))];                           %assign the orientation of the piece relative to channel centerline
                
                %find tress that span the channel
                if H_Mort(LWD_in(i)) == W_ch
                    LWD(A_Row,8) = 0.05;       %set LW function to nearly zero
                else
                    LWD(A_Row,8) = 0.5;     %otherwise, assume suspended on one bank only
                end
                                
                %BREAK the input wood based on its length
                [ Bflag H1 H2 ]= Break_In(LWD(A_Row,1));
                            %HWratio = LWD(A_Row,1) ./ 10;           %calculate the ratio the peice length to A REFERENCE PEICE 10 M LONG, SIMILAR TO WIDTH OF FT CREEK
                            %P_break = (1+ erf(2*HWratio-2.25))/2;   %calculate the probability of breakage based on an error function with  p =0.5 for len = width
                
                if Bflag == 1
                    %shorten the original piece
                    LWD(A_Row,1) = H1;
                    LWD(A_Row,8) = 0.5;  %make sure that the function class is hanging not spanning
                    LWD(A_Row,6) = 0;           %make sure that the piece is not part of a jam
                    LWD(A_Row,7) = 0;           %make sure the piece is not a key piece
                    
                    %and generate a new piece to be stored in the next row
                    B_Row = find(LWD(:,1) == 0,1, 'first');   %find the next available row to store data
                    
                    LWD(B_Row,1:4) = [ H2 ...   %assign the length of the piece, correcting for fall angle
                                    D_tr ...    %assign tree diamter
                                    0   ...     %set the age of the LWD piece to zero
                                    Ang_Mort(LWD_in(i)) ];    %assign the orientation of the piece relative to channel centerline
                    LWD(B_Row,6) = 0;           %make sure that the piece is not part of a jam
                    LWD(B_Row,7) = 0;           %make sure the piece is not a key piece
                    LWD(B_Row,8) = 0.95;         %set the LW function almost 1.0 (i.e. in the channel
                    
                end
            end        
        end

end

% SUBFUNCTIONS USED IN THIS FUNCTION
function [ Bflag H1 H2 ] = Break_In(L)
%Break_In.m is a function that calculates the probability of breakage for a
%piece entering the system with a peice length L
%   Detailed explanation goes here

    HWratio = L / 10;     %calculate the ratio the peice length to A REFERENCE PEICE 10 M LONG, SIMILAR TO WIDTH OF FT CREEK
    P_break = (1+ erf(2*HWratio-2.25))/2; 
     %this code can be used to visualize the error function
            %x=0:1:30
            %plot(x, (1+ erf(2*x-2.25))/2)
            
    %set the breakage flag to default of 0, and peice lengths to defaults
    Bflag = 0;
    H1 = L;
    H2 = 0;
    
    %break the piece if a uniform random number is less than the
    %probability of breakage
    if rand(1) < P_break    

        %break randomly near the middle
        H1 = L/4 + L/2 * rand(1);  %breakage occurs randomly between 25% and 75% of the length
        H2 = L - H1;
        Bflag = 1;
       
    end

end
